@@ -83,7 +83,7 @@ try:
     import gi
     gi.require_version('GConf','2.0')
     from gi.repository import GConf
-except ImportError:
+except ValueError:
     dbg('Unable to import gconf, GNOME defaults unavailable')
 
 DEFAULTS = {
