@@ -3,7 +3,7 @@
 # GPL v2 only
 """ipc.py - DBus server and API calls"""
 
-import gtk
+from gi.repository import Gdk
 import dbus.service
 from dbus.exceptions import DBusException
 import dbus.glib
@@ -19,11 +19,11 @@ if not CONFIG['dbus']:
     dbg('dbus disabled')
     raise ImportError
 
-BUS_BASE = 'net.tenshu.Terminator'
-BUS_PATH = '/net/tenshu/Terminator'
+BUS_BASE = 'net.tenshu.Terminator2'
+BUS_PATH = '/net/tenshu/Terminator2'
 try:
     # Try and include the X11 display name in the dbus bus name
-    DISPLAY  = hex(hash(gtk.gdk.get_display())).replace('-', '_')
+    DISPLAY  = hex(hash(Gdk.get_display())).replace('-', '_')
     BUS_NAME = '%s%s' % (BUS_BASE, DISPLAY)
 except:
     BUS_NAME = BUS_BASE
@@ -151,7 +151,7 @@ class DBusService(Borg, dbus.service.Object):
         return window.get_title()
 
     @dbus.service.method(BUS_NAME)
-    def get_terminal_tab(self, uuid):
+    def get_tab(self, uuid=None):
         """Return the UUID of the parent tab of a given terminal"""
         maker = Factory()
         terminal = self.terminator.find_terminal_by_uuid(uuid)
@@ -161,7 +161,7 @@ class DBusService(Borg, dbus.service.Object):
             return root_widget.uuid.urn
 
     @dbus.service.method(BUS_NAME)
-    def get_terminal_tab_title(self, uuid):
+    def get_tab_title(self, uuid=None):
         """Return the title of a parent tab of a given terminal"""
         maker = Factory()
         terminal = self.terminator.find_terminal_by_uuid(uuid)
