@@ -9,8 +9,8 @@ import os
 if __name__ == '__main__':
   sys.path.append( os.path.join(os.path.dirname(__file__), "../.."))
 
-import gtk
-import gobject
+from gi.repository import Gtk
+from gi.repository import GObject
 import terminatorlib.plugin as plugin
 from terminatorlib.config import Config
 from terminatorlib.translation import _
@@ -53,37 +53,37 @@ class CustomCommandsMenu(plugin.MenuItem):
                                 'command' : command
                               }
                             )
-      for cmd in noord_cmds:
-          self.cmd_list[len(self.cmd_list)] = cmd
+        for cmd in noord_cmds:
+            self.cmd_list[len(self.cmd_list)] = cmd
 
     def callback(self, menuitems, menu, terminal):
         """Add our menu items to the menu"""
-        item = gtk.MenuItem(_('_Custom Commands'))
+        item = Gtk.MenuItem.new_with_mnemonic(_('_Custom Commands'))
         menuitems.append(item)
 
-        submenu = gtk.Menu()
+        submenu = Gtk.Menu()
         item.set_submenu(submenu)
 
-        menuitem = gtk.ImageMenuItem(_('_Preferences'))
+        menuitem = Gtk.MenuItem.new_with_mnemonic(_('_Preferences'))
         menuitem.connect("activate", self.configure)
         submenu.append(menuitem)
 
-        menuitem = gtk.SeparatorMenuItem()
+        menuitem = Gtk.SeparatorMenuItem()
         submenu.append(menuitem)
 
-        theme = gtk.icon_theme_get_default()
+        theme = Gtk.IconTheme.get_default()
         for command in [ self.cmd_list[key] for key in sorted(self.cmd_list.keys()) ] :
           if not command['enabled']:
             continue
           exe = command['command'].split(' ')[0]
-          iconinfo = theme.choose_icon([exe], gtk.ICON_SIZE_MENU, gtk.ICON_LOOKUP_USE_BUILTIN)
+          iconinfo = theme.choose_icon([exe], Gtk.IconSize.MENU, Gtk.IconLookupFlags.USE_BUILTIN)
           if iconinfo:
-            image = gtk.Image()
-            image.set_from_icon_name(exe, gtk.ICON_SIZE_MENU)
-            menuitem = gtk.ImageMenuItem(command['name'])
+            image = Gtk.Image()
+            image.set_from_icon_name(exe, Gtk.IconSize.MENU)
+            menuitem = Gtk.ImageMenuItem(command['name'])
             menuitem.set_image(image)
           else:
-            menuitem = gtk.MenuItem(command["name"])
+            menuitem = Gtk.MenuItem(command["name"])
           terminals = terminal.terminator.get_target_terms(terminal)
           menuitem.connect("activate", self._execute, {'terminals' : terminals, 'command' : command['command'] })
           submenu.append(menuitem)
@@ -112,111 +112,111 @@ class CustomCommandsMenu(plugin.MenuItem):
       if command[-1] != '\n':
         command = command + '\n'
       for terminal in data['terminals']:
-        terminal.vte.feed_child(command)
+        terminal.vte.feed_child(command,  len(command))
 
     def configure(self, widget, data = None):
       ui = {}
-      dbox = gtk.Dialog(
+      dbox = Gtk.Dialog(
                       _("Custom Commands Configuration"),
                       None,
-                      gtk.DIALOG_MODAL,
+                      Gtk.DialogFlags.MODAL,
                       (
-                        gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
-                        gtk.STOCK_OK, gtk.RESPONSE_ACCEPT
+                        _("_Cancel"), Gtk.ResponseType.REJECT,
+                        _("_OK"), Gtk.ResponseType.ACCEPT
                       )
                     )
 
-      icon_theme = gtk.icon_theme_get_default()
+      icon_theme = Gtk.IconTheme.get_default()
       if icon_theme.lookup_icon('terminator-custom-commands', 48, 0):
         dbox.set_icon_name('terminator-custom-commands')
       else:
         dbg('Unable to load Terminator custom command icon')
-        icon = dbox.render_icon(gtk.STOCK_DIALOG_INFO, gtk.ICON_SIZE_BUTTON)
+        icon = dbox.render_icon(Gtk.STOCK_DIALOG_INFO, Gtk.IconSize.BUTTON)
         dbox.set_icon(icon)
 
-      store = gtk.ListStore(bool, str, str)
+      store = Gtk.ListStore(bool, str, str)
 
       for command in [ self.cmd_list[key] for key in sorted(self.cmd_list.keys()) ]:
         store.append([command['enabled'], command['name'], command['command']])
  
-      treeview = gtk.TreeView(store)
+      treeview = Gtk.TreeView(store)
       #treeview.connect("cursor-changed", self.on_cursor_changed, ui)
       selection = treeview.get_selection()
-      selection.set_mode(gtk.SELECTION_SINGLE)
+      selection.set_mode(Gtk.SelectionMode.SINGLE)
       selection.connect("changed", self.on_selection_changed, ui)
       ui['treeview'] = treeview
 
-      renderer = gtk.CellRendererToggle()
+      renderer = Gtk.CellRendererToggle()
       renderer.connect('toggled', self.on_toggled, ui)
-      column = gtk.TreeViewColumn(_("Enabled"), renderer, active=CC_COL_ENABLED)
+      column = Gtk.TreeViewColumn(_("Enabled"), renderer, active=CC_COL_ENABLED)
       treeview.append_column(column)
 
-      renderer = gtk.CellRendererText()
-      column = gtk.TreeViewColumn(_("Name"), renderer, text=CC_COL_NAME)
+      renderer = Gtk.CellRendererText()
+      column = Gtk.TreeViewColumn(_("Name"), renderer, text=CC_COL_NAME)
       treeview.append_column(column)
 
-      renderer = gtk.CellRendererText()
-      column = gtk.TreeViewColumn(_("Command"), renderer, text=CC_COL_COMMAND)
+      renderer = Gtk.CellRendererText()
+      column = Gtk.TreeViewColumn(_("Command"), renderer, text=CC_COL_COMMAND)
       treeview.append_column(column)
 
-      scroll_window = gtk.ScrolledWindow()
+      scroll_window = Gtk.ScrolledWindow()
       scroll_window.set_size_request(500, 250)
-      scroll_window.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+      scroll_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
       scroll_window.add_with_viewport(treeview)
 
-      hbox = gtk.HBox()
-      hbox.pack_start(scroll_window, True, True)
-      dbox.vbox.pack_start(hbox)
+      hbox = Gtk.HBox()
+      hbox.pack_start(scroll_window, True, True, 0)
+      dbox.vbox.pack_start(hbox, True, True, 0)
 
-      button_box = gtk.VBox()
+      button_box = Gtk.VBox()
 
-      button = gtk.Button(stock=gtk.STOCK_GOTO_TOP)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Top"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_goto_top, ui) 
       button.set_sensitive(False)
       ui['button_top'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_GO_UP)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Up"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_go_up, ui)
       button.set_sensitive(False)
       ui['button_up'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_GO_DOWN)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Down"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_go_down, ui) 
       button.set_sensitive(False)
       ui['button_down'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_GOTO_LAST)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Last"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_goto_last, ui) 
       button.set_sensitive(False)
       ui['button_last'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_NEW)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("New"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_new, ui) 
       ui['button_new'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_EDIT)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Edit"))
+      button_box.pack_start(button, False, True, 0)
       button.set_sensitive(False)
       button.connect("clicked", self.on_edit, ui) 
       ui['button_edit'] = button
 
-      button = gtk.Button(stock=gtk.STOCK_DELETE)
-      button_box.pack_start(button, False, True)
+      button = Gtk.Button(_("Delete"))
+      button_box.pack_start(button, False, True, 0)
       button.connect("clicked", self.on_delete, ui) 
       button.set_sensitive(False)
       ui['button_delete'] = button
 
 
 
-      hbox.pack_start(button_box, False, True)
+      hbox.pack_start(button_box, False, True, 0)
       dbox.show_all()
       res = dbox.run()
-      if res == gtk.RESPONSE_ACCEPT:
+      if res == Gtk.ResponseType.ACCEPT:
         self.update_cmd_list(store)
         self._save_config()
       dbox.destroy()
@@ -262,36 +262,36 @@ class CustomCommandsMenu(plugin.MenuItem):
       data['button_delete'].set_sensitive(iter is not None)
 
     def _create_command_dialog(self, enabled_var = False, name_var = "", command_var = ""):
-      dialog = gtk.Dialog(
+      dialog = Gtk.Dialog(
                         _("New Command"),
                         None,
-                        gtk.DIALOG_MODAL,
+                        Gtk.DialogFlags.MODAL,
                         (
-                          gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
-                          gtk.STOCK_OK, gtk.RESPONSE_ACCEPT
+                          _("_Cancel"), Gtk.ResponseType.REJECT,
+                          _("_OK"), Gtk.ResponseType.ACCEPT
                         )
                       )
-      table = gtk.Table(3, 2)
+      table = Gtk.Table(3, 2)
 
-      label = gtk.Label(_("Enabled:"))
+      label = Gtk.Label(label=_("Enabled:"))
       table.attach(label, 0, 1, 0, 1)
-      enabled = gtk.CheckButton()
+      enabled = Gtk.CheckButton()
       enabled.set_active(enabled_var)
       table.attach(enabled, 1, 2, 0, 1)
 
-      label = gtk.Label(_("Name:"))
+      label = Gtk.Label(label=_("Name:"))
       table.attach(label, 0, 1, 1, 2)
-      name = gtk.Entry()
+      name = Gtk.Entry()
       name.set_text(name_var)
       table.attach(name, 1, 2, 1, 2)
       
-      label = gtk.Label(_("Command:"))
+      label = Gtk.Label(label=_("Command:"))
       table.attach(label, 0, 1, 2, 3)
-      command = gtk.Entry()
+      command = Gtk.Entry()
       command.set_text(command_var)
       table.attach(command, 1, 2, 2, 3)
 
-      dialog.vbox.pack_start(table)
+      dialog.vbox.pack_start(table, True, True, 0)
       dialog.show_all()
       return (dialog,enabled,name,command)
 
@@ -299,15 +299,15 @@ class CustomCommandsMenu(plugin.MenuItem):
       (dialog,enabled,name,command) = self._create_command_dialog()
       res = dialog.run()
       item = {}
-      if res == gtk.RESPONSE_ACCEPT:
+      if res == Gtk.ResponseType.ACCEPT:
         item['enabled'] = enabled.get_active()
         item['name'] = name.get_text()
         item['command'] = command.get_text()
         if item['name'] == '' or item['command'] == '':
-          err = gtk.MessageDialog(dialog,
-                                  gtk.DIALOG_MODAL,
-                                  gtk.MESSAGE_ERROR,
-                                  gtk.BUTTONS_CLOSE,
+          err = Gtk.MessageDialog(dialog,
+                                  Gtk.DialogFlags.MODAL,
+                                  Gtk.MessageType.ERROR,
+                                  Gtk.ButtonsType.CLOSE,
                                   _("You need to define a name and command")
                                 )
           err.run()
@@ -409,15 +409,15 @@ class CustomCommandsMenu(plugin.MenuItem):
                                                                   )
       res = dialog.run()
       item = {}
-      if res == gtk.RESPONSE_ACCEPT:
+      if res == Gtk.ResponseType.ACCEPT:
         item['enabled'] = enabled.get_active()
         item['name'] = name.get_text()
         item['command'] = command.get_text()
         if item['name'] == '' or item['command'] == '':
-          err = gtk.MessageDialog(dialog,
-                                  gtk.DIALOG_MODAL,
-                                  gtk.MESSAGE_ERROR,
-                                  gtk.BUTTONS_CLOSE,
+          err = Gtk.MessageDialog(dialog,
+                                  Gtk.DialogFlags.MODAL,
+                                  Gtk.MessageType.ERROR,
+                                  Gtk.ButtonsType.CLOSE,
                                   _("You need to define a name and command")
                                 )
           err.run()
@@ -445,5 +445,5 @@ class CustomCommandsMenu(plugin.MenuItem):
 if __name__ == '__main__':
   c = CustomCommandsMenu()
   c.configure(None, None)
-  gtk.main()
+  Gtk.main()
 
